#delimit ;
set more off;

/*

*11-05-2002 UI BENEFIT CALCULATOR 1984-2000

*This program uses information on state UI laws obtained from the DoL
 (contact Suzanne Simonetta <ssimonetta@doleta.gov> for details)
 to identify the path of UI benefits for a given individual.  It updates 

 and extends an earlier UI calculator due to Jon Gruber and Julie Cullen

*BEFORE running this do file, do three things:
 1. merge the file uilaws.dta onto your sample by sippst (FIPS state code)
 2. merge the file statecodes.dta onto your sample by sippst: this gives you a crosswalk to the st state code variable used by this program
 3. construct the inputs listed below for each obs in your data.

*This program only assigns benefits for the states in the SIPP.  

  The following small states are excluded:
  Maine, Vermont, Iowa, N. Dakota, S. Dakota, Alaska, Idaho, Montana, Wyoming;

*Output variables:
	-wba = weekly benefit amount
	-maxdur = maximum duration of benefits (in weeks)

Input variables used:
	- bpw  = base period wage
	- hq1w = highest quarter wage (among quarters in base period)
	- hq2w = second highest quarter wage
	- hq12sum  = 2 high quarters wage sum
	- annwg = annual earnings
      - tao (avg tax rate, for MI)
	- kids = number of kids
	- spwork_yn = working spouse dummy
      - tenure (weeks employed prior to job separation, for computation of duration of bens)
      - empcens (dummy for left-censored tenure, used in computation of duration of bens)
	- year (YYYY)
	- part of year (part=1 for Jan-Jun and part=2 for Jul-Dec)
	- pbpw = max proportion of base period wages payable in UI benefits
	- dur_min = minimum number of weeks for duration
	- dur_max = maximum number of weeks for duration
	- wba_min = minimum wba allowed
	- wba_max = maximum wba allowed
	- st  = Cullen-Gruber alphabetical state number (note that this is NOT the same as FIPS; use statecodes.dta as a crosswalk; see readme file):

    st       name
     1         AL
     2         AZ
     3         AR
     4         CA
     5         CO
     6         CT
     7         DE
     8         DC
     9         FL
    10         GA
    11         ID
    12         IL
    13         IN
    14         IA
    15         KS
    16         KY
    17         LA
    18         ME
    19         MD
    20         MA
    21         MI
    22         MN
    23         MS
    24         MO
    25         MT
    26         NE
    27         NV
    28         NH
    29         NJ
    30         NM
    31         NY
    32         NC
    33         ND
    34         OH
    35         OK
    36         OR
    37         PA
    38         RI
    39         SC
    40         SD
    41         TN
    42         TX
    43         UT
    44         VT
    45         VA
    46         WA
    47         WV
    48         WI
    49         WY
    50         AK
    51         HI
-------------------------------------------------------------------- 
*/

*1 BENEFIT AMOUNTS;

gen hq12sum = hq1w +hq2w;
gen hq13sum = bpw*(3/4);
gen wg = annwg/50;

/*Alabama*/
gen wba=(1/24)*(hq12sum)/2 if st==1;

/*Arizona*/
replace wba=(1/25)*hq1w if st==2;

/*Arkansas*/
replace wba=(1/52)*hq12sum if st==3;
replace wba=(1/26)*hq1w if st==3&nndate>19910700;

/*California*/

/*830101-900101*/

replace wba=30  if st==04 & nndate>=19830101 & nndate<19900101 & hq1w<689;
replace wba=31+(1/30)*(hq1w-689) if st==04 & nndate>=19830101 & 
  nndate<19900101 & hq1w>=689 & hq1w<2000;
replace wba=75+(1/37)*(hq1w-2000) if st==04 & nndate>=19830101 & 
  nndate<19900101 & hq1w>=2000 & hq1w<3000;
replace wba=102+(1/45)*(hq1w-3000) if st==04 & nndate>=19830101 & 
  nndate<19900101 & hq1w>=3000 & hq1w<4000;
replace wba=124+(1/37)*(hq1w-4000) if st==04 & nndate>=19830101 & 
  nndate<19900101 & hq1w>=4000 & hq1w<5533;
replace wba=166 if st==04 & nndate>=19830101 & nndate<19900101 & hq1w>=5533;

/*1990 and beyond*/
replace wba=40+(0.0338)*(hq1w-949) if st==04 & nndate>=19900100 &
  hq1w>=949 & hq1w<1976;
replace wba=75+(0.0265)*(hq1w-1976) if st==04 & nndate>=19900100 
  & hq1w>=1976 & hq1w<3029;
replace wba=102+(0.0217)*(hq1w-3029) if st==04 & nndate>=19900100
  & hq1w>=3029 & hq1w<4043;
replace wba=124+(0.027)*(hq1w-4043) if st==04 & nndate>=19900100
  & hq1w>=4043 & hq1w<4697;
replace wba=0.39*(hq1w/13) if st==04 & nndate>=19900100
  & hq1w>=4697;

/*Colorado*/
replace wba=.6*(1/26)*hq12sum if st==5;
replace wba=min(.6*(1/26)*hq12sum,.5*(1/52)*bpw) if st==5&nndate>=19920700;

/*Connecticut*/
replace wba=(1/26)*hq1w if st==6;
replace wba=(1/52)*hq12sum if st==6 & nndate>=19940100;

*Add the dependent allowance;
replace wba=wba+min(10*kids,.5*wba,50) if st==6;
*Adjust the wba_min for dependents;
replace wba_min=wba_min+min(10*kids,.5*wba,50) if st==6;
*Adjust the wba_max for dependents;
replace wba_max=wba_max+min(10*kids,.5*wba,50) if st==6;



/*Delaware*/
replace wba=(1/46)*hq12sum if st==7;
replace wba=(1/78)*hq13sum if st==7 & nndate>=19760105&nndate<19880101;

/*District of Columbia*/
replace wba=(1/23)*hq1w if st==8;
replace wba=(1/26)*hq1w if st==8 & nndate>=19930100;
replace wba=wba+min(5*kids,20) if st==8&nndate<=19980700;

/*Florida*/
replace wba=.5*wg if st==9;
replace wba=(1/26)*hq1w if st==9&nndate>=19960700;

/*Georgia*/
replace wba=(1/50)*hq12sum if st==10;
replace wba=(1/48)*hq12sum if st==10 & nndate>=19970700;

/*Hawaii*/
replace wba=(1/25)*hq1w if st==51;
replace wba=(1/21)*hq1w if st==51&nndate>=19920100;

/*Illinois*/

* For years up to 1987 (note: ill_staww computed from lowest wba_max, entered in uilaws.dta);
replace wba = .48*(1/26)*hq12sum if st==12& nndate<19880100;
gen ill_staww = wba_max/.48 if st==12&nndate<=19880100;
*Compute the maximum wba;
replace wba_max = .624*ill_staww if st==12&kids>0 & nndate<19880100;
replace wba_max = .55*ill_staww if st==12&spwork_yn==0&kids==0 & nndate<19880100;
replace wba_max = .48*ill_staww if st==12&spwork_yn~=0&kids==0 & nndate<19880100;

* For 1988 to 1992;
replace wba = .49*(1/26)*hq12sum if st==12& nndate>=19880100 & nndate<19930100;
replace ill_staww = wba_max/.49 if st==12&nndate<=19930100;
*Compute the maximum wba;
replace wba_max = .64*ill_staww if st==12&kids>0 & nndate>=19880100 & nndate<19930100;
replace wba_max = .57*ill_staww if st==12&spwork_yn==0&kids==0 & nndate>=19880100 &nndate<19930100;
replace wba_max = .49*ill_staww if st==12&spwork_yn~=0&kids==0 & nndate>=19880100 &nndate<19930100;

* For 1993 and following years;
replace wba = .495*(1/26)*hq12sum if st==12&nndate>=19930100;
replace ill_staww = wba_max/.495 if st==12&nndate>=19930100;
*Compute the maximum wba;  
replace wba_max = .655*ill_staww if st==12&kids>0&nndate>=19930100;
replace wba_max = .585*ill_staww if st==12&spwork_yn==0&kids==0&nndate>=19930100;
replace wba_max = .495*ill_staww if st==12&spwork_yn~=0&kids==0&nndate>=19930100;

drop ill_staww;

/*Indiana*/

replace wba=.043*hq1w if st==13; 

replace wba_min=35 if st==13 & nndate>=19780102 & nndate<19800706;
replace wba_min=40 if st==13 & nndate>=19800706 & nndate<19910707;
replace wba_min=50 if st==13 & nndate>=19910707;

/*770703-800706*/

replace wba_max=74 if st==13 & kids==0 & nndate>=19770703 &nndate<19800706;
replace wba_max=87 if st==13 & kids==1 & nndate>=19770703 & nndate<19800706;
replace wba_max=99 if st==13 & kids==2 & nndate>=19770703 & nndate<19800706;
replace wba_max=112 if st==13 & kids==3 & nndate>=19770703 & nndate<19800706;
replace wba_max=124 if st==13 & kids>=4 & nndate>=19770703 & nndate<19800706;

/*800706-850701*/

replace wba_max=84 if st==13 & kids==0 & nndate>=19800706 & nndate<19850701;
replace wba_max=99 if st==13 & kids==1 & nndate>=19800706 & nndate<19850701;
replace wba_max=113 if st==13 & kids==2 & nndate>=19800706 & nndate<19850701;
replace wba_max=128 if st==13 & kids==3 & nndate>=19800706 & nndate<19850701;
replace wba_max=141 if st==13 & kids>=4 & nndate>=19800706 & nndate<19850701;

/*850701-860701*/

replace wba_max=90 if st==13 & kids==0 & nndate>=19850701 & nndate<19860701;
replace wba_max=106 if st==13 & kids==1 & nndate>=19850701 & nndate<19860701;
replace wba_max=121 if st==13 & kids==2 & nndate>=19850701 & nndate<19860701;
replace wba_max=138 if st==13 & kids==3 & nndate>=19850701 & nndate<19860701;
replace wba_max=151 if st==13 & kids>=4 & nndate>=19850701 & nndate<19860701;

/*860701-910707*/

replace wba_max=96 if st==13 & kids==0 & nndate>=19860701 & nndate<19910707;
replace wba_max=113 if st==13 & kids==1 & nndate>=19860701 & nndate<19910707;
replace wba_max=129 if st==13 & kids==2 & nndate>=19860701 & nndate<19910707;
replace wba_max=147 if st==13 & kids==3 & nndate>=19860701 & nndate<19910707;
replace wba_max=161 if st==13 & kids>=4 & nndate>=19860701 & nndate<19910707;

/*910707-920705*/

replace wba_max=116 if st==13 & kids==0 & nndate>=19910707 & nndate<19920705;
replace wba_max=134 if st==13 & kids==1 & nndate>=19910707 & nndate<19920705;
replace wba_max=153 if st==13 & kids==2 & nndate>=19910707 & nndate<19920705;
replace wba_max=171 if st==13 & kids>=3 & nndate>=19910707 & nndate<19920705;

/*920705-930704*/

replace wba_max=140 if st==13 & kids==0 & nndate>=19920705 & nndate<19930704;
replace wba_max=160 if st==13 & kids==1 & nndate>=19920705 & nndate<19930704;
replace wba_max=181 if st==13 & kids>=2 & nndate>=19920705 & nndate<19930704;

replace wba_max=170 if st==13 & kids==0 & nndate>=19930704 & nndate<19940703;
replace wba_max=192 if st==13 & kids>=1 & nndate>=19930704 & nndate<19940703;

replace wba_max=202 if st==13 & nndate>=19940703;

replace wba=wba_max if wba>wba_max & st==13;
replace wba=wba_min if wba<wba_min & st==13;


/*Kansas*/
replace wba=.0425*hq1w if st==15;

/*Kentucky*/
replace wba=.01185*bpw if st==16;

/*Louisiana*/
replace wba=(1/20)*hq1w if st==17 & wg<875 & nndate<19880700;
replace wba=(1/25)*hq1w if st==17 & wg>=875 & nndate<19880700;
replace wba=(1/25)*(1/4)*bpw if st==17 & nndate>=19880700;

/*Maryland*/

replace wba=(1/24)*hq1w if st==19;
replace wba=wba+min(8*kids,40) if st==19&nndate>=19890700;

/*Massachusetts*/

replace wba =(1/26)*hq1w if st==20;
replace wba = 14 if st==20 & hq1w<300 & nndate>19730101;
replace wba = 14 + (1/22)*(hq1w - 300) if st==20 & hq1w>=300 
  & hq1w<542 & nndate>19730101;
replace wba = 25 + (1/42)*(hq1w - 542) if st==20 & hq1w>=542 
  & hq1w<858 & nndate>19730101;
replace wba=(1/26)*hq1w if st==20 & hq1w>=858 & nndate>19730101;

replace wba_min=14 if st==20 & nndate>=19731001;

replace wba=wba_min if wba<=wba_min & st==20;

replace wba_max=142 if st==20 & nndate>=19801001 & nndate<19811001;
replace wba_max=156 if st==20 & nndate>=19811001 & nndate<19821001;
replace wba_max=172 if st==20 & nndate>=19821001 & nndate<19831001;
replace wba_max=185 if st==20 & nndate>=19831001 & nndate<19841001;
replace wba_max=196 if st==20 & nndate>=19841001 & nndate<19851001;
replace wba_max=207 if st==20 & nndate>=19851001 & nndate<19861001;
replace wba_max=220 if st==20 & nndate>=19861001 & nndate<19880103;
replace wba_max=236 if st==20 & nndate>=19880103 & nndate<19890101;
replace wba_max=255 if st==20 & nndate>=19890101 & nndate<19900107;
replace wba_max=272 if st==20 & nndate>=19900107 & nndate<19910106;
replace wba_max=282 if st==20 & nndate>=19910106 & nndate<19920105;
replace wba_max=296 if st==20 & nndate>=19920105 & nndate<19930103;
replace wba_max=312 if st==20 & nndate>=19930103 & nndate<19940102;
replace wba_max=325 if st==20 & nndate>=19940102 & nndate<19941001;
replace wba_max=336 if st==20 & nndate>=19941001;

/* Add Dependant Allowances to wba */

replace wba=wba+min(6*kids,(1/2)*wba) if st==20 & nndate>=19700701 & nndate<=19870309;
replace wba_max=wba_max+min(6*kids,(1/2)*wba) if st==20 & nndate>=19700701 & nndate<=19870309;

replace wba=wba+min(15*kids,(1/2)*wba) if st==20 & nndate>=19870309 & nndate<=19880101;
replace wba_max=wba_max+min(15*kids,(1/2)*wba) if st==20 & nndate>=19870309 & nndate<=19880101;

replace wba=wba+min(25*kids,(1/2)*wba) if st==20 & nndate>=19880101;
replace wba_max=wba_max+min(25*kids,(1/2)*wba) if st==20 & nndate>=19880101;



/*Michigan*/
replace wba=.7*(1-tao)*wg if st==21;
replace wba=.65*(1-tao)*wg if st==21 & nndate>=19830101 & nndate<19870101;
replace wba=.7*(1-tao)*wg if st==21 & nndate>=19870101;


/*Minnesota*/

/*default case*/
replace wba = 1/26*hq1w if st==22;

/*exceptions pre-1990*/
replace wba=.6*wg if wg<85 & st==22 & nndate>=19760105 & nndate<19880103;
replace wba=.6*85+.4*(wg-85) if wg>=85 & wg<170 & st==22 
  & nndate>=19760105 & nndate<19880103;
replace wba=.6*85+.4*85+.5*(wg-170) if wg>=170 & st==22 & 
  nndate>=19760105 & nndate<19880103;
replace wba = 1/26*hq1w if st==22 & nndate>=19880103;


/*Mississippi*/
replace wba=(1/26)*hq1w if st==23;

/*Missouri*/
replace wba=.045*hq1w if st==24;
replace wba=.040*hq1w if st==24 & nndate>=19980700;

/*Nebraska*/
replace wba=12+max(.04*(hq1w-200),0) if st==26;

/*Nevada*/
replace wba=(1/25)*hq1w if st==27;

/*New Hampshire*/

/*790901-810901*/

replace wba=0 if st==28 & nndate>=19790901 & nndate<19830701 & annwg<1200;

replace wba=min(21+.01*(annwg-1200),114) if st==28 & nndate>=19790901 &
  nndate<19830701 & annwg>=1200;

replace wba_max=114 if st==28 & nndate>=19790901 & nndate<19830701;
replace wba_min=21  if st==28 & nndate>=19790901 & nndate<19830701;

/*810901-830701*/

replace wba=0 if st==28 & nndate>=19810901 & nndate<19830701 & annwg<1700;
replace wba=26+.01*(annwg-1700) if st==28 & nndate>=19810901 & 
  nndate<19830701 & annwg>=1700 & annwg<10500;
replace wba=min(114+.003*(annwg-10500),132) if st==28 & nndate>=19810901
  & nndate<19830701 & annwg>=10500;

replace wba_max=132 if st==28 & nndate>=19810901 & nndate<19830701;
replace wba_min=26  if st==28 & nndate>=19810901 & nndate<19830701;

/*830701-850901*/

replace wba=0 if st==28 & nndate>=19830701 & nndate<19850901 & annwg<1700;
replace wba=26+.01*(annwg-1700) if st==28 & nndate>=19830701 & 
  nndate<19850901 & annwg>=1700 & annwg<10500;
replace wba=min(114+.003*(annwg-10500),141) if st==28 & nndate>=19830701
  & nndate<19850901 & annwg>=10500;

replace wba_max=141 if st==28 & nndate>=19830701 & nndate<19850901;
replace wba_min=26  if st==28 & nndate>=19830701 & nndate<19850901;

/*850901-870701*/

replace wba=0 if st==28 & nndate>=19850901 & nndate<19870701 & annwg<2600;
replace wba=36+.01*(annwg-2600) if st==28 & nndate>=19850901 & nndate<19870701 &
  annwg>=2600 & annwg<10500;
replace wba=min(114+.003*(annwg-10500),150) if st==28 & nndate>=19850901 &
  nndate<19870701 & annwg>=10500;

replace wba_max=150 if st==28 & nndate>=19850901 & nndate<19870701;
replace wba_min=36  if st==28 & nndate>=19850901 & nndate<19870701;

/*870701-890702*/

replace wba=0 if st==28 & nndate>=19870701 & annwg<2800;
replace wba=39+.0103*(annwg-2800) if st==28 & nndate>=19870701 & nndate<19890702
  & annwg>=2800 & annwg<9500;

replace wba=108+.006*(annwg-9500) if st==28 & nndate>=19870701 & 
  nndate<19890702 & annwg>=9500 & annwg<11500;
replace wba=min(120+.003*(annwg-11500),156) if st==28 & nndate>=19870701 &
  nndate<19890702 & annwg>=11500;

replace wba_max=156 if st==28 & nndate>=19870701 & nndate<19890702;
replace wba_min=39  if st==28 & nndate>=19870701 & nndate<19890702;

/*890702-900107*/

replace wba=0 if st==28 & nndate>=19890702 & nndate<19900107 & annwg<2800;
replace wba=35+.0117*(annwg-2800) if st==28 & nndate>=19890702 & nndate<19900107
  & annwg>=2800 & annwg<9500;
replace wba=108+.006*(annwg-9500) if st==28 & nndate>=19890702 & 
  nndate<19900107 & annwg>=9500 & annwg<11500;
replace wba=120+.003*(annwg-11500) if st==28 & nndate>=19890702 & 
  nndate<19900107 & annwg>=11500 & annwg<15500;
replace wba=min(132+.004*(annwg-15500),162) if st==28 & nndate>=19890702 
  & nndate<19900107 & annwg>=15500;

replace wba_max=162 if st==28 & nndate>=19890702 & nndate<19900107;
replace wba_min=35  if st==28 & nndate>=19890702 & nndate<19900107;

/*900107-910630*/

replace wba=0 if st==28 & nndate>=19900107 & nndate<19910630 & annwg<2800;
replace wba=35+.0117*(annwg-2800) if st==28 & nndate>=19900107 & 
  nndate<19910630 & annwg>=2800 & annwg<9500;
replace wba=108+.006*(annwg-9500) if st==28 & nndate>=19900107 & 
  nndate<19910630 & annwg>=9500 & annwg<11500;
replace wba=120+.003*(annwg-11500) if st==28 & nndate>=19900107 & 
  nndate<19910630 & annwg>=11500 & annwg<15500;
replace wba=132+.004*(annwg-15500) if st==28 & nndate>=19900107 & 
  nndate<19910630 & annwg>=15500 & annwg<21500;
replace wba=min(156+.006*(annwg-21500),168) if st==28 & nndate>=19900107
  & nndate<19910630 & annwg>=21500;

replace wba_max=168 if st==28 & nndate>=19900107 & nndate<19910630;
replace wba_min=35  if st==28 & nndate>=19900107 & nndate<19910630;

/*910630-920329*/

replace wba=0 if st==28 & nndate>=19910630 & nndate<19920329 & annwg<2800;
replace wba=34+.0116*(annwg-2800) if st==28 & nndate>=19910630 & nndate<19920329
  & annwg>=2800 & annwg<9500;
replace wba=min(108+.0045*(annwg-9500),179) if st==28 & nndate>=19910630 &
  nndate<19920329 & annwg>=9500;

replace wba_max=179 if st==28 & nndate>=19910630 & nndate<19920329;
replace wba_min=34  if st==28 & nndate>=19910630 & nndate<19920329;

/*920329-930704*/

replace wba=0 if st==28 & nndate>=19920329 & annwg<2800;
replace wba=32+.0112*(annwg-2800) if st==28 & nndate>=19920329 
  & annwg>=2800 & annwg<9500;
replace wba=108+.008*(annwg-9500) if st==28 & nndate>=19920329 
  & annwg>=9500 & annwg<12500;
replace wba=min(131+.006*(annwg-12500), 188) if st==28 & nndate>=19920329 
  & nndate<19930704 & annwg>=12500;

replace wba_max=188 if st==28 & nndate>=19920329 & nndate<19930704;
replace wba_min=32  if st==28 & nndate>=19920329 ;

/*930704-940327*/

replace wba=min(131+.006*(annwg-12500),196) if st==28 & nndate>=19930704 & 
  nndate<19940327 & annwg>=12500;

replace wba_max=196 if st==28 & nndate>=19930704 & nndate<19940327;

/*940327-?*/
  
replace wba=min(131+.006*(annwg-12500),204) if st==28 & nndate>=19940327
  & annwg>=12500;

replace wba_max=204 if st==28 & nndate>=19940327;


/*New Jersey: state source says no change from 85 to 94*/

replace wba=.6*wg if st==29 & nndate>=19850100;

replace wba=wba+.07*wg if kids==1 & st==29 & nndate>=19850100;
replace wba=wba+.11*wg if kids==2 & st==29 & nndate>=19850100;
replace wba=wba+.15*wg if kids>=3 & st==29 & nndate>=19850100;


/*New Mexico*/
replace wba=(1/26)*hq1w if st==30;

/*New York*/
replace wba=.5*wg if st==31;

/*North Carolina*/
replace wba=(1/52)*hq12sum if st==32;
replace wba=(1/26)*hq1w if st==32 & nndate>=19950100;


/*Ohio*/
replace wba=(1/2)*wg if st==34;
replace wba_min=10 if st==34;

/*1980*/

replace wba_max=128 if st==34 & nndate>=19800101 & nndate<19810101 & kids==0;
replace wba_max=293 if st==34 & nndate>=19800101 & nndate<19810101 & kids>=1 & kids<3;
replace wba_max=202 if st==34 & nndate>=19800101 & nndate<19810101 & kids>=3;

/*1981*/

replace wba_max=136 if st==34 & nndate>=19810101 & nndate<19820101 & kids==0;
replace wba_max=206 if st==34 & nndate>=19810101 & nndate<19820101 & kids>=1 & kids<3;
replace wba_max=215 if st==34 & nndate>=19810101 & nndate<19820101 & kids>=3;

/*1982-1987*/

replace wba_max=147 if st==34 & nndate>=19820101 & nndate<19880101 & kids==0;
replace wba_max=223 if st==34 & nndate>=19820101 & nndate<19880101 & kids>=1 & kids<3;
replace wba_max=233 if st==34 & nndate>=19820101 & nndate<19880101 & kids>=3;

/*1988*/

replace wba_max=157 if st==34 & nndate>=19880101 & nndate<19890101 & kids==0;
replace wba_max=238 if st==34 & nndate>=19880101 & nndate<19890101 & kids>=1 & kids<3;
replace wba_max=248 if st==34 & nndate>=19880101 & nndate<19890101 & kids>=3;

/*1989*/

replace wba_max=169 if st==34 & nndate>=19890101 & nndate<19900101 & kids==0;
replace wba_max=257 if st==34 & nndate>=19890101 & nndate<19900101 & kids>=1 & kids<3;
replace wba_max=268 if st==34 & nndate>=19890101 & nndate<19900101 & kids>=3;

/*1990*/

replace wba_max=184 if st==34 & nndate>=19900101 & nndate<19910101 & kids==0;
replace wba_max=279 if st==34 & nndate>=19900101 & nndate<19910101 & kids>=1 & kids<3;
replace wba_max=291 if st==34 & nndate>=19900101 & nndate<19910101 & kids>=3;

/*1991*/

replace wba_max=196 if st==34 & nndate>=19910101 & nndate<19920101 & kids==0;
replace wba_max=279 if st==34 & nndate>=19910101 & nndate<19920101 & kids>=1 & kids<3;
replace wba_max=291 if st==34 & nndate>=19910101 & nndate<19920101 & kids>=3;

/*1992*/

replace wba_max=211 if st==34 & nndate>=19920101 & nndate<19930101 & kids==0;
replace wba_max=279 if st==34 & nndate>=19920101 & nndate<19930101 & kids>=1 & kids<3;
replace wba_max=294 if st==34 & nndate>=19920101 & nndate<19930101 & kids>=3;

/*1993*/

replace wba_max=228 if st==34 & nndate>=19930101 & nndate<19940101 & kids==0;
replace wba_max=279 if st==34 & nndate>=19930101 & nndate<19940101 & kids>=1 & kids<3;
replace wba_max=306 if st==34 & nndate>=19930101 & nndate<19940101 & kids>=3;
 
/*1994*/

replace wba_max=238 if st==34 & nndate>=19940101 & nndate<19950101 & kids==0;
replace wba_max=288 if st==34 & nndate>=19940101 & nndate<19950101 & kids>=1 & kids<3;
replace wba_max=319 if st==34 & nndate>=19940101 & nndate<19950101 & kids>=3;

/*1995*/
replace wba_max=245 if st==34 & nndate>=19950101 & nndate<19960101 & kids==0;
replace wba_max=295 if st==34 & nndate>=19950101 & nndate<19960101 & kids>=1 & kids<3;
replace wba_max=328 if st==34 & nndate>=19950101 & nndate<19960101 & kids>=3;

/*Oklahoma*/
replace wba=(1/25)*hq1w if st==35;
replace wba=(1/23)*hq1w if st==35 & nndate>=19980700;

/*Oregon*/
replace wba=.0125*bpw if st==36;

/*Pennsylvania  (from Levine) */

replace wba_max=wba_max + min(5+(kids-1)*3,8) if kids>0 & st==37 & nndate>=19720101;
replace wba_min=wba_min + min(5+(kids-1)*3,8) if kids>0 & st==37 & nndate>=19720101;
replace wba=wba_min if st==37 & nndate>=19780101 & nndate<19810101 & hq1w<263;
replace wba=wba_min+(1/25)*(hq1w-263) if st==37 & nndate>=19720101 &
  nndate<19810101 & hq1w>=263;
replace wba=wba_min if st==37 & nndate>=19810101 & hq1w<813;
replace wba=wba_min+(1/25)*(hq1w-813) if st==37 & nndate>=19810101
  & hq1w>=813;
replace wba=wba+min(5+(kids-1)*3,8) if kids>0 & st==37 & nndate>=19720101;


/*Rhode Island*/

replace wba=.55*wg if st==38 & nndate<19880100;
replace wba=.6*wg if st==38 & nndate>=19880100 & nndate<19900100;
replace wba=.0462*hq1w if st==38&nndate>=19900100;

replace wba=wba+min(5*kids,20) if st==38 & nndate>=19680707 & nndate<19860105;
*Adjust max and min for dependents
replace wba_max=wba_max+min(5*kids,20) if st==38 & nndate>=19680707 & nndate<19860105;
replace wba_min=wba_min+min(5*kids,20) if st==38 & nndate>=19680707 & nndate<19860105;

replace wba=wba+min(kids,5)*max(5,.05*wba) if st==38 & nndate>=19860105 & nndate<19880103;
*Adjust max and min for dependents
replace wba_max=wba_max+min(kids,5)*max(5,.05*wba) if st==38 & nndate>=19860105 & nndate<19880103;
replace wba_min=wba_min+min(kids,5)*max(5,.05*wba) if st==38 & nndate>=19860105 & nndate<19880103;

replace wba=wba + min(kids,5)*max(10,.05*wba) if st==38 & nndate>=19880103;
*Adjust max and min for dependents
replace wba_max=wba_max+min(kids,5)*max(10,.05*wba) if st==38 & nndate>=19880103;
replace wba_min=wba_min+min(kids,5)*max(10,.05*wba) if st==38 & nndate>=19880103;



/*South Carolina*/
replace wba=(1/26)*hq1w if st==39;

/*Tennessee*/

replace wba=(1/26)*hq1w if st==41 & nndate<19800701;

replace wba=30 if st==41 & nndate>=19890702 & nndate<19900107 & hq1w<780;
replace wba=30+(1/26)*(hq1w-780) if st==41 & nndate>=19890702 & 
  nndate<19900107 & hq1w>=780 & hq1w<1846;
replace wba=71+(1/37)*(hq1w-1846) if st==41 & nndate>=19890702 & 
  nndate<19900107 & hq1w>=1846 & hq1w<4991;
replace wba=155 if st==41 & nndate>=19890702 & nndate<19900107 & hq1w>=4991;

replace wba=(1/26)*hq12sum if st==41 & nndate>=19940703;


/*7/80-6/83*/

replace wba=20 if st==41 & nndate>=19800701 & nndate<19830701 & hq1w<494;
replace wba=20+(1/26)*(hq1w-494) if st==41 & nndate>=19800701 & 
  nndate<19830701 & hq1w>=494 & hq1w<1820;
replace wba=70+(1/40)*(hq1w-1820) if st==41 & nndate>=19800701 & 
  nndate<19830701 & hq1w>=1820 & hq1w<3420;
replace wba=110 if st==41 & nndate>=19800701 & nndate<19830701 & hq1w>=3420;

/*7/83-12/83*/

replace wba=30 if st==41 & nndate>=19830701 & nndate<19840101 & hq1w<754;
replace wba=30+(1/26)*(hq1w-754) if st==41 & nndate>=19830701 & 
  nndate<19840101 & hq1w>=754 & hq1w<1820;
replace wba=70+(1/40)*(hq1w-1820) if st==41 & nndate>=19830701 & 
  nndate<19840101 & hq1w>=1820 & hq1w<3420;
replace wba=110 if st==41 & nndate>=19830701 & nndate<19840101 & hq1w>=3420;

/*1/84-12/84*/

replace wba=30 if st==41 & nndate>=19840101 & nndate<19850101 & hq1w<754;
replace wba=30+(1/26)*(hq1w-754) if st==41 & nndate>=19840101 & 
  nndate<19850101 & hq1w>=754 & hq1w<1820;
replace wba=70+(1/40)*(hq1w-1820) if st==41 & nndate>=19840101 & 
  nndate<19850101 & hq1w>=1820 & hq1w<3620;
replace wba=115 if st==41 & nndate>=19840101 & nndate<19850101 & hq1w>=3620;

/*1/85-6/86*/

replace wba=30 if st==41 & nndate>=19850101 & nndate<19860701 & hq1w<754;
replace wba=30+(1/26)*(hq1w-754) if st==41 & nndate>=19850101 & 
  nndate<19860701 & hq1w>=754 & hq1w<1820;
replace wba=70+(1/40)*(hq1w-1820) if st==41 & nndate>=19850101 & 
  nndate<19860701 & hq1w>=1820 & hq1w<3820;
replace wba=120 if st==41 & nndate>=19850101 & nndate<19860701 & hq1w>=3820;

/*7/86-12/86*/

replace wba=30 if st==41 & nndate>=19860701 & nndate<19870101 & hq1w<754;
replace wba=30+(1/26)*(hq1w-754) if st==41 & nndate>=19860701 & 
  nndate<19870101 & hq1w>=754 & hq1w<1820;
replace wba=70+(1/40)*(hq1w-1820) if st==41 & nndate>=19860701 & 
  nndate<19870101 & hq1w>=1820 & hq1w<4020;
replace wba=125 if st==41 & nndate>=19860701 & nndate<19870101 & hq1w>=4020;

/*1/87-6/87*/

replace wba=30 if st==41 & nndate>=19870101 & nndate<19870701 & hq1w<754;
replace wba=30+(1/26)*(hq1w-754) if st==41 & nndate>=19870101 & 
  nndate<19870701 & hq1w>=754 & hq1w<1820;
replace wba=70+(1/40)*(hq1w-1820) if st==41 & nndate>=19870101 & 
  nndate<19870701 & hq1w>=1820 & hq1w<4220;
replace wba=130 if st==41 & nndate>=19870101 & nndate<19870701 & hq1w>=4220;

/*7/87-7/2/88*/

replace wba=30 if st==41 & nndate>=19870701 & nndate<19880702 & hq1w<754;
replace wba=30+(1/26)*(hq1w-754) if st==41 & nndate>=19870701 & 
  nndate<19880702 & hq1w>=754 & hq1w<1820;
replace wba=70+(1/40)*(hq1w-1820) if st==41 & nndate>=19870701 & 
  nndate<19880702 & hq1w>=1820 & hq1w<4820;
replace wba=145 if st==41 & nndate>=19870701 & nndate<19880702 & hq1w>=4820;

/*7/3/88-7/1/89*/

replace wba=30 if st==41 & nndate>=19880703 & nndate<19890702 & hq1w<754;
replace wba=30+(1/26)*(hq1w-754) if st==41 & nndate>=19880703 & 
  nndate<19890702 & hq1w>=754 & hq1w<1820;
replace wba=70+(1/40)*(hq1w-1820) if st==41 & nndate>=19880703 & 
  nndate<19890702 & hq1w>=1820 & hq1w<4820;
replace wba=145 if st==41 & nndate>=19880703 & nndate<19890702 & hq1w>=4820;

/*7/2/89-1/6/90*/

replace wba=30 if st==41 & nndate>=19890702 & nndate<19900107 & hq1w<780;
replace wba=30+(1/26)*(hq1w-780) if st==41 & nndate>=19890702 & 
  nndate<19900107 & hq1w>=780 & hq1w<1846;
replace wba=71+(1/37)*(hq1w-1846) if st==41 & nndate>=19890702 & 
  nndate<19900107 & hq1w>=1846 & hq1w<4991;
replace wba=155 if st==41 & nndate>=19890702 & nndate<19900107 & hq1w>=4991;

/*1/7/90-7/5/90*/

replace wba=30 if st==41 & nndate>=19900107 & nndate<19900705 & hq1w<780;
replace wba=30+(1/26)*(hq1w-780) if st==41 & nndate>=19900107 & 
  nndate<19900705 & hq1w>=780 & hq1w<1846;
replace wba=71+(1/37)*(hq1w-1846) if st==41 & nndate>=19900107 & 
  nndate<19900705 & hq1w>=1846 & hq1w<5176;
replace wba=160 if st==41 & nndate>=19900107 & nndate<19900705 & hq1w>=5176;

/*7/5/90-1/6/91*/

replace wba=30 if st==41 & nndate>=19900705 & nndate<19910106 & hq1w<780;
replace wba=30+(1/26)*(hq1w-780) if st==41 & nndate>=19900705 & 
  nndate<19910106 & hq1w>=780 & hq1w<1846;
replace wba=71+(1/34)*(hq1w-1846) if st==41 & nndate>=19900705 & 
  nndate<19910106 & hq1w>=1846 & hq1w<4906;
replace wba=160 if st==41 & nndate>=19900705 & nndate<19910106 & hq1w>=4906;

/*1/6/91-7/7/91*/

replace wba=30 if st==41 & nndate>=19910106 & nndate<19910707 & hq1w<780;
replace wba=30+(1/26)*(hq1w-780) if st==41 & nndate>=19910106
  & nndate<19910707 & hq1w>=780 & hq1w<1846;
replace wba=71+(1/34)*(hq1w-1846) if st==41 & nndate>=19910106
  & nndate<19910707 & hq1w>=1846 & hq1w<5076;
replace wba=165 if st==41 & nndate>=19910106 & nndate<19910707 & hq1w>=5076;

/*7/7/91-1/5/92*/

replace wba=30 if st==41 & nndate>=19910707 & nndate<19920105 & hq1w<780;
replace wba=30+(1/26)*(hq1w-780) if st==41 & nndate>=19910707
  & nndate<19920105 & hq1w>=780 & hq1w<1846;
replace wba=71+(1/28)*(hq1w-1846) if st==41 & nndate>=19910707
  & nndate<19920105 & hq1w>=1846 & hq1w<4506;
replace wba=165 if st==41 & nndate>=19910707 & nndate<19920105 & hq1w>=4506;

/*1/5/92-7/5/92*/

replace wba=30 if st==41 & nndate>=19920105 & nndate<19920705 & hq1w<780;
replace wba=30+(1/26)*(hq1w-780) if st==41 & nndate>=19920105
  & nndate<19920705 & hq1w>=780 & hq1w<1846;
replace wba=71+(1/28)*(hq1w-1846) if st==41 & nndate>=19920105
  & nndate<19920705 & hq1w>=1846 & hq1w<4506;
replace wba=165 if st==41 & nndate>=19920105 & nndate<19920705 & hq1w>=4506;

/*7/5/92-7/4/93*/

replace wba=30 if st==41 & nndate>=19920705 & nndate<19930704 & hq1w<780;
replace wba=30+(1/26)*(hq1w-780) if st==41 & nndate>=19920705
 & nndate<19930704 & hq1w>=780 & hq1w<4420;
replace wba=170 if st==41 & nndate>=19920705 & nndate<19930704 & hq1w>=4420;

/*7/4/93-7/3/94*/

replace wba=30 if st==41 & nndate>=19930704 & nndate<19940703 & hq1w<780;
replace wba=30+(1/26)*(hq1w-780) if st==41 & nndate>=19930704
  & nndate<19940703 & hq1w>=780 & hq1w<4810;
replace wba=185 if st==41 & nndate>=19930704 & nndate<19940703 & hq1w>=4810;

/*7/3/94+*/

replace wba=30 if st==41 & nndate>=19940703 & hq1w<780;
replace wba=30+(1/26)*(hq1w-780) if st==41 & nndate>=19940703
  & hq1w>=780 & hq1w<5200;
replace wba=200 if st==41 & nndate>=19940703 & hq1w>=5200;


/*Texas*/
replace wba=(1/25)*hq1w if st==42;

/*Utah*/
replace wba=(1/26)*hq1w if st==43;

/*Virginia*/
replace wba=(1/50)*hq12sum if st==45;

/*Washington*/
replace wba=(1/50)*hq12sum if st==46;


/*West Virginia*/
replace wba =.01*annwg if st==47;

/*19780701 to 19830701*/

replace wba = 0  if annwg<1150 & st==47 & nndate>=19780701 & nndate<=19830701;
replace wba = 18 + (annwg-1150)/150 if annwg>=1150 & annwg<2500 & st==47 & 
  nndate>=19780701 & nndate<=19830701;
replace wba = (0.001*annwg + 2) if annwg>=2500 & annwg<3200 & st==47 & 
  nndate>=19780701 & nndate<=19830701;
replace wba = 35 + 1.59*((annwg-3200)/150) if annwg>=3200 & st==47 & 
  nndate>=19780701 & nndate<=19830701;

/*19830701 to 19850701*/

replace wba = 0  if annwg<1150 & st==47 & nndate>=19830701 & nndate<=19850701;
replace wba = 18 + (annwg-1150)/150 if annwg>=1150 & annwg<2500 & st==47 & 
  nndate>=19830701 & nndate<=19850701;
replace wba = (0.001*annwg + 2) if annwg>=2500 & annwg<3200 & st==47 & 
  nndate>=19830701 & nndate<=19850701;
replace wba = 35 + 1.58*((annwg-3200)/150) if annwg>=3200 & st==47 & 
  nndate>=19830701 & nndate<=19850701;


replace wba = 0 if annwg<2200 & st==47 & nndate>=19850701;
replace wba = 24 + 1.58*(annwg-2200)/150 if annwg>=2200 & st==47 & 
  nndate>=19850701;

/*Wisconsin*/
replace wba=.5*wg if st==48;
replace wba=.04*(hq1w) if st==48&nndate>19920700;


*Final adjustments (deal with min/maxes);

replace wba=wba_max if wba>wba_max;
*Next statement is dangerous -- need to make sure wba_min=0;
replace wba_min=0 if wba_min==.;
replace wba=wba_min if wba<wba_min;


drop hq12sum hq13sum wg;


* MAX DURATION OF BENEFITS;

replace tenure=100 if empcens==1;
gen maxdur=.5*tenure if st==9;
replace maxdur=.75*tenure if st==21;
replace maxdur=.75*tenure if st==29;

replace maxdur= (pbpw * bpw) / wba;

replace maxdur=dur_max if maxdur>dur_max;
replace dur_min=0 if dur_min==.;
replace maxdur=dur_min if maxdur<dur_min;

replace maxdur = round(maxdur,1);

**DEAL WITH FEDERAL AND STATE EXTENDED BENEFITS PROGRAMS;

replace maxdur = 39 if nndate>=19901117&nndate<=19940206;

